# PythonPackageIndexesIndexes

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**url** | **str** | URL to the Python simple repository as described in PEP 503. |
**warehouse_api_url** | **str** | URL to the warehouse API. |
**verify_ssl** | **bool** | Use secured connection to warehouse. |

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

